package com.qxgmat.controller.admin;


import com.nuliji.tools.Response;
import com.nuliji.tools.ResponseHelp;
import com.nuliji.tools.Transform;
import com.qxgmat.data.dao.entity.Question;
import com.qxgmat.data.relation.entity.QuestionNoRelation;
import com.qxgmat.dto.admin.extend.QuestionNoExtendDto;
import com.qxgmat.dto.admin.request.QuestionDto;
import com.qxgmat.dto.admin.request.QuestionNoSearchDto;
import com.qxgmat.service.ExercisePaperService;
import com.qxgmat.service.inline.ManagerLogService;
import com.qxgmat.service.inline.QuestionNoService;
import com.qxgmat.service.inline.QuestionService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

@RestController("AdminQuestionController")
@RequestMapping("/admin/question")
@Api(tags = "题目接口", description = "题目相关", produces = MediaType.APPLICATION_JSON_VALUE)
public class QuestionController {

    @Autowired
    private ManagerLogService managerLogService;

    @Autowired
    private ExercisePaperService exercisePaperService;

    @Autowired
    private QuestionNoService questionNoService;

    @Autowired
    private QuestionService questionService;

    @RequestMapping(value = "/add", method = RequestMethod.POST)
    @ApiOperation(value = "添加题目", httpMethod = "POST")
    public Response<Question> add(@RequestBody @Validated QuestionDto dto, HttpServletRequest request) {
        Question entity = Transform.dtoToEntity(dto);
        // 添加
//        entity.setModule(QuestionModule.EXERCISE.key);
        entity = exercisePaperService.addQuestion(entity);
        managerLogService.log(request);
        return ResponseHelp.success(entity);
    }

    @RequestMapping(value = "/edit", method = RequestMethod.PUT)
    @ApiOperation(value = "修改题目", httpMethod = "PUT")
    public Response<Boolean> edit(@RequestBody @Validated QuestionDto dto, HttpServletRequest request) {
        Question entity = Transform.dtoToEntity(dto);
        // 添加
//        entity.setModule(QuestionModule.EXERCISE.key);
//        entity = exercisePaperService.editQuestion(entity);
        managerLogService.log(request);
        return ResponseHelp.success(true);
    }

    @RequestMapping(value = "/delete", method = RequestMethod.DELETE)
    @ApiOperation(value = "删除题目", httpMethod = "DELETE")
    public Response<Boolean> delete(int id, HttpServletRequest request) {
//        Question entity = Transform.dtoToEntity(dto);
        // 添加
//        entity.setModule(QuestionModule.EXERCISE.key);
//        entity = exercisePaperService.editQuestion(entity);
        managerLogService.log(request);
        return ResponseHelp.success(true);
    }

    @RequestMapping(value = "/list/no", method = RequestMethod.POST)
    @ApiOperation(value = "题目编号列表：通过编号", httpMethod = "POST")
    public Response<List<QuestionNoExtendDto>> listNo(@RequestBody @Validated QuestionNoSearchDto dto, HttpServletRequest request) {
        List<QuestionNoRelation> questionNos = questionNoService.listByNos(dto.getNo(), dto.getModule());
        List<QuestionNoExtendDto> questionNoExtendDtos = Transform.convert(questionNos, QuestionNoExtendDto.class);

        return ResponseHelp.success(questionNoExtendDtos);
    }

    @RequestMapping(value = "/search/stem", method = RequestMethod.GET)
    @ApiOperation(value = "搜索题目编号列表：题干搜索", httpMethod = "GET")
    public Response<List<QuestionNoExtendDto>> searchStem(
            @RequestParam(required = false, defaultValue = "1") int page,
            @RequestParam(required = false, defaultValue = "100") int size,
            @RequestParam(required = false, name="stem") String stem,
            HttpServletRequest request) {
        List<QuestionNoRelation> questionNos = questionNoService.searchStem(page, size, stem);
        List<QuestionNoExtendDto> questionNoExtendDtos = Transform.convert(questionNos, QuestionNoExtendDto.class);

        return ResponseHelp.success(questionNoExtendDtos);
    }

    @RequestMapping(value = "/search/no", method = RequestMethod.GET)
    @ApiOperation(value = "搜索题目编号列表：题干搜索", httpMethod = "GET")
    public Response<List<QuestionNoExtendDto>> searchNo(
            @RequestParam(required = false, defaultValue = "1") int page,
            @RequestParam(required = false, defaultValue = "100") int size,
            @RequestParam(required = false, name="no") String no,
            HttpServletRequest request) {
        List<QuestionNoRelation> questionNos = questionNoService.searchNo(page, size, no);
        List<QuestionNoExtendDto> questionNoExtendDtos = Transform.convert(questionNos, QuestionNoExtendDto.class);

        return ResponseHelp.success(questionNoExtendDtos);
    }
}
